@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,8 +12,6 @@
 #
 ##############################################################################
 """Test handler for Annotation Role Permission Manager.
-
-$Id: test_annotationrolepermissionmanager.py 98091 2009-03-14 11:20:13Z nadako $
 """
 import unittest
 from zope.component import provideUtility, provideAdapter
@@ -25,7 +23,7 @@ from zope.security.interfaces import IPermission
 from zope.security.permission import Permission
 
 from zope.securitypolicy.role import Role
-from zope.securitypolicy.interfaces import Allow, Deny
+from zope.securitypolicy.interfaces import Allow, Deny, Unset
 from zope.securitypolicy.interfaces import IRole
 from zope.securitypolicy.rolepermission import AnnotationRolePermissionManager
 
@@ -87,6 +85,9 @@ class Test(PlacelessSetup, unittest.TestCase):
         l = list(mgr.getRolesForPermission(self.read))
         self.assertEqual(l, [(self.manager, Allow)])
 
+        self.assertEqual(mgr.getSetting(self.read, self.peon), Unset)
+        self.assertEqual(mgr.getSetting(self.read, self.peon, 1), 1)
+
 
 def test_suite():
     loader=unittest.TestLoader()
