@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,11 +12,9 @@
 #
 ##############################################################################
 """Doctests for 'permission' module.
-
-$Id: test_role.py 80107 2007-09-26 14:58:39Z rogerineichen $
 """
+from doctest import DocTestSuite
 import unittest
-from zope.testing.doctestunit import DocTestSuite
 
 
 def test_suite():
@@ -26,4 +24,3 @@ def test_suite():
 
 if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
-
