@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,11 +12,9 @@
 #
 ##############################################################################
 """Role vocabluary doc tests.
-
-$Id: test_vocabulary.py 80107 2007-09-26 14:58:39Z rogerineichen $
 """
+from doctest import DocTestSuite
 import unittest
-from zope.testing.doctestunit import DocTestSuite
 
 def test_suite():
     return unittest.TestSuite((
